@@ -1,4 +1,5 @@
 import librosa
+import gc
 import numpy as np
 from datetime import datetime, timedelta
 from .singleton import Singleton
@@ -296,15 +297,6 @@ class FeatureEmbedder(Singleton):
         audio_time_series, sample_rate = librosa.load(
             audio_file_path, sr=self.frequency
         )
-        FeatureEmbedder.__LOGGER.debug(
-            "Audio file loaded with sample rate {}: {}".format(
-                sample_rate, audio_file_path
-            )
-        )
-
-        audio_load_time = datetime.now() - t
-
-        t = datetime.now()
 
         # Get MFCC features
         mfcc = librosa.feature.mfcc(
@@ -313,6 +305,14 @@ class FeatureEmbedder(Singleton):
             hop_length=int(self.__hop_len),
             n_mfcc=self.__n_mfcc,
         )
+        del audio_time_series
+        gc.collect()
+
+        FeatureEmbedder.__LOGGER.debug(
+            "Audio file loaded and embedded with sample rate {}: {}".format(
+                sample_rate, audio_file_path
+            )
+        )
 
         # Group multiple MFCCs of 32 ms into a larger range for LSTM
         # and each stride will have an overlay with the previous one
@@ -323,6 +323,8 @@ class FeatureEmbedder(Singleton):
         samples = samples[: int((mfcc.shape[1] - len_mfcc) / step_mfcc) + 1]
 
         train_data = np.stack(samples)
+        del samples
+        gc.collect()
 
         mfcc_extration_time = datetime.now() - t
 
@@ -350,9 +352,6 @@ class FeatureEmbedder(Singleton):
         FeatureEmbedder.__LOGGER.debug(
             "| Subtitle file path: {}".format(subtitle_file_path)
         )
-        FeatureEmbedder.__LOGGER.debug(
-            "| Audio load time: {}".format(str(audio_load_time))
-        )
         FeatureEmbedder.__LOGGER.debug(
             "| MFCC extration time: {}".format(str(mfcc_extration_time))
         )
