@@ -5,17 +5,18 @@ from hyperopt.pyll.base import scope
 from .trainer import Trainer
 from .embedder import FeatureEmbedder
 from .hyperparameters import Hyperparameters
+from .network import Network
 
 
 class HyperParameterTuner(object):
-    """Hyper parameter tuning using the Bayesian Optimizer"""
+    """Hyper parameter tuning using the Tree of Parzen Estimators algorithm"""
 
     SEARCH_SPACE = {
         "learning_rate": hp.loguniform("learning_rate", np.log(0.00001), np.log(0.1)),
         "front_hidden_size": hp.choice("front_hidden_size", [[16], [32], [64]]),
         "back_hidden_size": hp.choice("back_hidden_size", [[16, 8], [32, 16]]),
         "batch_size": scope.int(hp.qloguniform("batch_size", np.log(8), np.log(4096), 1)),
-        "optimizer": hp.choice("optimizer", ["adam", "sgd", "rms", "adagrad"]),
+        "optimizer": hp.choice("optimizer", Hyperparameters.OPTIMIZERS),
         "dropout": hp.loguniform("dropout", np.log(0.1), np.log(0.3)),
         "validation_split": hp.loguniform("validation_split", np.log(0.2), np.log(0.4)),
     }
@@ -25,7 +26,8 @@ class HyperParameterTuner(object):
                  subtitle_file_paths,
                  training_dump_dir,
                  num_of_trials=5,
-                 tuning_epochs=5):
+                 tuning_epochs=5,
+                 network_type=Network.LSTM):
         """Hyper parameter tuner initialiser
 
         Arguments:
@@ -36,12 +38,18 @@ class HyperParameterTuner(object):
         Keyword Arguments:
             num_of_trials {int} -- The number of trials for tuning (default: {5}).
             tuning_epochs {int} -- The number of training epochs for each trial (default: {5}).
+            network_type {string} -- The type of the network (default: {"lstm"}, range: ["lstm", "bi_lstm", "conv_1d"]).
         """
+
+        assert network_type in Network.TYPES, "Supported network type values: %s" % Network.TYPES
+        hyperparameters = Hyperparameters()
+        hyperparameters.network_type = network_type
+        self.__hyperparameters = hyperparameters
+
         self.__trainer = Trainer(FeatureEmbedder())
         self.__av_file_paths = av_file_paths
         self.__subtitle_file_paths = subtitle_file_paths
         self.__training_dump_dir = training_dump_dir
-        self.__hyperparameters = Hyperparameters()
         self.__num_of_trials = num_of_trials
         self.__tuning_epochs = tuning_epochs
         self.__original_epochs = self.__hyperparameters.epochs
